@@ -281,13 +281,12 @@ static int Tcc4tclCreateCmd( ClientData cdata, Tcl_Interp *interp, int objc, Tcl
 
 int Tcc4tcl_Init(Tcl_Interp *interp) {
 #ifdef USE_TCL_STUBS
-	if (Tcl_InitStubs(interp, "8.4" , 0) == 0L) {
+	if (Tcl_InitStubs(interp, TCL_VERSION , 0) == 0L) {
 		return TCL_ERROR;
 	}
 #endif
 
-	Tcl_CreateObjCommand(interp, PACKAGE_NAME, Tcc4tclCreateCmd, NULL, NULL);
-	Tcl_PkgProvide(interp, PACKAGE_NAME, PACKAGE_VERSION);
+	Tcl_CreateObjCommand(interp, "tcc4tcl", Tcc4tclCreateCmd, NULL, NULL);
 
 	return TCL_OK;
 }
